<?php
/*
 * ReviewPaging
 * Copyright (C) 2012 LOCKON CO.,LTD. All Rights Reserved.
 * http://www.lockon.co.jp/
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


/* 
 * カテゴリ毎にコンテンツを設定する事ができます。
 */
class ReviewPaging extends SC_Plugin_Base {

    /**
     * コンストラクタ
     * プラグイン情報(dtb_plugin)をメンバ変数をセットします.
     * @param array $arrSelfInfo dtb_pluginの情報配列
     * @return void
     */
    public function __construct(array $arrSelfInfo) {
        parent::__construct($arrSelfInfo);
    }

    /**
     * インストール時に実行される処理を記述します.
     * @param array $arrPlugin dtb_pluginの情報配列
     * @return void
     */
    function install($arrPlugin) {
        // ロゴファイルをhtmlディレクトリにコピーします.
        copy(PLUGIN_UPLOAD_REALDIR . $arrPlugin['plugin_code'] . "/logo.png", PLUGIN_HTML_REALDIR . $arrPlugin['plugin_code'] . "/logo.png");
    }

    /**
     * 削除時に実行される処理を記述します.
     * @param array $arrPlugin dtb_pluginの情報配列
     * @return void
     */
    function uninstall($arrPlugin) {
    }
    
    /**
     * 有効にした際に実行される処理を記述します.
     * @param array $arrPlugin dtb_pluginの情報配列
     * @return void
     */
    function enable($arrPlugin) {
        // nop
    }

    /**
     * 無効にした際に実行される処理を記述します.
     * @param array $arrPlugin dtb_pluginの情報配列
     * @return void
     */
    function disable($arrPlugin) {
        // nop
    }

    /**
     * prefilterコールバック関数
     * テンプレートの変更処理を行います.
     *
     * @param string &$source テンプレートのHTMLソース
     * @param LC_Page_Ex $objPage ページオブジェクト
     * @param string $filename テンプレートのファイル名
     * @return void
     */
    function prefilterTransform(&$source, LC_Page_Ex $objPage, $filename) {
        // SC_Helper_Transformのインスタンスを生成.
        $objTransform = new SC_Helper_Transform($source);
		$template_dir = PLUGIN_UPLOAD_REALDIR . 'ReviewPagingItoben/templates/';
        // 呼び出し元テンプレートを判定します.
        switch($objPage->arrPageLayout['device_type_id']){
            case DEVICE_TYPE_MOBILE: // モバイル
            default:
                break;
            case DEVICE_TYPE_SMARTPHONE: // スマホ
            default:
                break;
            case DEVICE_TYPE_PC: // PC
                // 商品詳細ページ
                if (strpos($filename, 'products/detail.tpl') !== false) {
                    // id=customervoice_area要素の前にプラグイン側で用意したテンプレートを挿入します.
                    $objTransform->select('div#customervoice_area')->insertBefore(file_get_contents($template_dir . 'plg_css.tpl'));
                }
                if (strpos($filename, 'products/detail.tpl') !== false) {
                    // class=review_btn要素をプラグイン側で用意したテンプレートと置き換えます.
                    $objTransform->select('div.review_btn')->replaceElement(file_get_contents($template_dir . 'plg_review_btn.tpl'));
                }
                if (strpos($filename, 'products/detail.tpl') !== false) {
                    // id=customervoice_area内のulをプラグイン側で用意したテンプレートと置き換えます.
                    $objTransform->select('div#customervoice_area ul')->replaceElement(file_get_contents($template_dir . 'plg_ul.tpl'));
                }
                break;
            case DEVICE_TYPE_ADMIN:
            default:
                break;
        }

        // 変更を実行します
        $source = $objTransform->getHTML();
    }
    
    /**
     * 処理の介入箇所とコールバック関数を設定
     * registerはプラグインインスタンス生成時に実行されます
     * 
     * @param SC_Helper_Plugin $objHelperPlugin 
     */
    function register(SC_Helper_Plugin $objHelperPlugin) {
		$objHelperPlugin->addAction('prefilterTransform',array(&$this, 'prefilterTransform'));
    }
}

?>
